4.4. umbra.components.addons.tcpClientUi.tcpClientUi — Umbra 1.0.4 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »

# 4.4. umbra.components.addons.tcpClientUi.tcpClientUi

tcpClientUi.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines the `TCPClientUi` Component Interface class.

Others:

## 4.4.1. Module Attributes

`umbra.components.addons.tcpClientUi.tcpClientUi.` `LOGGER`

`umbra.components.addons.tcpClientUi.tcpClientUi.` `COMPONENT_UI_FILE`

## 4.4.2. Classes

class `umbra.components.addons.tcpClientUi.tcpClientUi.` `TCPClientUi`(parent=None, name=None, *args, **kwargs)

  Bases: `manager.qwidgetComponent.QWidgetComponent`

  This class is the `umbra.components.factory.tcpClientUi.tcpClientUi` Component Interface class.

  Parameters: | parent – Object parent. ( QObject ) name – Component name. ( String ) *args – Arguments. ( * ) **kwargs – Keywords arguments. ( ** )

  `engine`

    This method is the property for self.__engine attribute.

    Returns: | self.__engine. ( QObject )

  `settings`

    This method is the property for self.__settings attribute.

    Returns: | self.__settings. ( QSettings )

  `settingsSection`

    This method is the property for self.__settingsSection attribute.

    Returns: | self.__settingsSection. ( String )

  `preferencesManager`

    This method is the property for self.__preferencesManager attribute.

    Returns: | self.__preferencesManager. ( QWidget )

  `scriptEditor`

    This method is the property for self.__scriptEditor attribute.

    Returns: | self.__scriptEditor. ( QWidget )

  `address`

    This method is the property for self.__address attribute.

    Returns: | self.__address. ( String )

  `port`

    This method is the property for self.__port attribute.

    Returns: | self.__port. ( Integer )

  `fileCommand`

    This method is the property for self.__fileCommand attribute.

    Returns: | self.__fileCommand. ( String )

  `connectionEnd`

    This method is the property for self.__connectionEnd attribute.

    Returns: | self.__connectionEnd. ( String )

  `activate`(engine)

    This method activates the Component.

    Parameters: | engine – Engine to attach the Component to. ( QObject )
    Returns: | Method success. ( Boolean )

  `deactivate`()

    This method deactivates the Component.

    Returns: | Method success. ( Boolean )

  `initializeUi`()

    This method initializes the Component ui.

    Returns: | Method success. ( Boolean )

  `uninitializeUi`()

    This method uninitializes the Component ui.

    Returns: | Method success. ( Boolean )

  `addWidget`()

    This method adds the Component Widget to the engine.

    Returns: | Method success. ( Boolean )

  `removeWidget`()

    This method removes the Component Widget from the engine.

    Returns: | Method success. ( Boolean )

  `sendDataToServer`(data, timeOut=5)

    This method sends given data to the Server.

    Parameters: | data – Data to send. ( String ) timeOut – Connection timeout in seconds. ( Float )
    Returns: | Method success. ( Boolean )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »